( cd usr/bin ; rm -rf pnmnoraw )
( cd usr/bin ; ln -sf pnmtoplainpnm pnmnoraw )
( cd usr/bin ; rm -rf gemtopbm )
( cd usr/bin ; ln -sf gemtopnm gemtopbm )
( cd usr/bin ; rm -rf ppmtojpeg )
( cd usr/bin ; ln -sf pnmtojpeg ppmtojpeg )
( cd usr/bin ; rm -rf bmptoppm )
( cd usr/bin ; ln -sf bmptopnm bmptoppm )
( cd usr/bin ; rm -rf ppmtouil )
( cd usr/bin ; ln -sf pamtouil ppmtouil )
( cd usr/bin ; rm -rf pnmtopnm )
( cd usr/bin ; ln -sf pamtopnm pnmtopnm )
( cd usr/bin ; rm -rf pnmtofits )
( cd usr/bin ; ln -sf pamtofits pnmtofits )
( cd usr/bin ; rm -rf pnmtotiff )
( cd usr/bin ; ln -sf pamtotiff pnmtotiff )
( cd usr/bin ; rm -rf pgmslice )
( cd usr/bin ; ln -sf pamslice pgmslice )
( cd usr/bin ; rm -rf pnmfile )
( cd usr/bin ; ln -sf pamfile pnmfile )
( cd usr/bin ; rm -rf pgmoil )
( cd usr/bin ; ln -sf pamoil pgmoil )
( cd usr/bin ; rm -rf pnminterp )
( cd usr/bin ; ln -sf pamstretch pnminterp )
( cd usr/bin ; rm -rf ppmnorm )
( cd usr/bin ; ln -sf pnmnorm ppmnorm )
( cd usr/bin ; rm -rf pgmnorm )
( cd usr/bin ; ln -sf pnmnorm pgmnorm )
( cd usr/bin ; rm -rf pgmedge )
( cd usr/bin ; ln -sf pamedge pgmedge )
( cd usr/bin ; rm -rf pnmenlarge )
( cd usr/bin ; ln -sf pamenlarge pnmenlarge )
( cd usr/bin ; rm -rf pnmarith )
( cd usr/bin ; ln -sf pamarith pnmarith )
( cd usr/bin ; rm -rf pnmsplit )
( cd usr/bin ; ln -sf pamsplit pnmsplit )
( cd usr/bin ; rm -rf pnmdepth )
( cd usr/bin ; ln -sf pamdepth pnmdepth )
( cd usr/lib64 ; rm -rf libnetpbm.so.10 )
( cd usr/lib64 ; ln -sf libnetpbm.so.10.35 libnetpbm.so.10 )
( cd usr/lib64 ; rm -rf libnetpbm.so )
( cd usr/lib64 ; ln -sf libnetpbm.so.10 libnetpbm.so )
